@@ -5,6 +5,8 @@ from openpyxl import \
     Workbook, \
     load_workbook
 
+from domain.hiss_immobilizer.HissImmobilizerData import HissImmobilizerData
+from domain.hiss_immobilizer.HissImmobilizerSheet import HissImmobilizerSheet
 from xlsx_lib.domain.components.ComponentsData import ComponentsData
 from xlsx_lib.domain.components.ComponentsSheet import ComponentsSheet
 from xlsx_lib.domain.shared.NewImageFile import NewImageFile
@@ -15,7 +17,7 @@ from xlsx_lib.domain.abs.AbsData import AbsData
 from xlsx_lib.domain.abs.AbsSheet import AbsSheet
 from xlsx_lib.domain.autodiagnosis.AutodiagnosisData import AutodiagnosisData
 from xlsx_lib.domain.autodiagnosis.AutodiagnosisSheet import AutodiagnosisSheet
-from xlsx_lib.domain.distribution.distribution_sheet import DistributionData, DistributionSheet
+from xlsx_lib.domain.distribution.DistributionSheet import DistributionData, DistributionSheet
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
 from xlsx_lib.domain.power_supply.power_supply_sheet import PowerSupplySheet
 from xlsx_lib.domain.frame.frame_element import FrameElement
@@ -65,6 +67,7 @@ class MotorcycleModelWorkbook:
         abs_data: Optional[AbsData] = None
         smart_key_data: Optional[SmartKeyData] = None
         components_data: Optional[ComponentsData] = None
+        hiss_immobilizer_data: Optional[HissImmobilizerData] = None
 
         for sheetname in [key for key in workbook.sheetnames
                           if key in SHEETNAMES_RELATIONSHIPS]:
@@ -112,6 +115,9 @@ class MotorcycleModelWorkbook:
                 components_data = components_sheet.components_data
                 self.components_image = components_sheet.components_image
 
+            elif Sheetnames.HISS_INMOBILIZER == SHEETNAMES_RELATIONSHIPS[sheetname]:
+                hiss_immobilizer_data = HissImmobilizerSheet(worksheet=workbook[sheetname]).hiss_immobilizer_data
+
         self.motorcycle_model = XlsxMotorcycleModel(
             model_name=model_name,
             generic_replacements=generic_replacements,
@@ -125,4 +131,5 @@ class MotorcycleModelWorkbook:
             abs_data=abs_data,
             smart_key_data=smart_key_data,
             components_data=components_data,
+            hiss_immobilizer_data=hiss_immobilizer_data,
         )
