@@ -2,11 +2,12 @@ from typing import Optional, List
 
 from camel_model.camel_model import CamelModel
 
+from domain.hiss_immobilizer.HissImmobilizerData import HissImmobilizerData
 from xlsx_lib.domain.components.ComponentsData import ComponentsData
 from xlsx_lib.domain.smart_key.SmartKeyData import SmartKeyData
 from xlsx_lib.domain.abs.AbsData import AbsData
 from xlsx_lib.domain.autodiagnosis.AutodiagnosisData import AutodiagnosisData
-from xlsx_lib.domain.distribution.distribution_data import DistributionData
+from xlsx_lib.domain.distribution.DistributionData import DistributionData
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
 from xlsx_lib.domain.electronic.electronic_element import ElectronicElement
 
@@ -28,4 +29,5 @@ class XlsxMotorcycleModel(CamelModel):
     autodiagnosis: Optional[AutodiagnosisData]
     abs_data: Optional[AbsData]
     smart_key_data: Optional[SmartKeyData]
-    components: Optional[ComponentsData]
\ No newline at end of file
+    components_data: Optional[ComponentsData]
+    hiss_immobilizer_data: Optional[HissImmobilizerData]
