@@ -6,7 +6,7 @@ from xlsx_lib.domain.tightening_specifications.tightening_torque_step import Tig
 
 
 class Screw(CamelModel):
-    name: str
+    name: Optional[str]
     tightening_specification: Optional[str]
     steps: Optional[List[TighteningSpecificationStep]]
     detail: Optional[str]
